/*
 * @Company: hugeInfo
 * @Author: lwh
 * @Date: 2022-03-08 09:32:36
 * @LastEditTime: 2022-04-02 15:58:49
 * @LastEditors: lwh
 * @Version: 1.0.0
 * @Description: 客户管理-编辑页面
 */
import React, { useState, useEffect } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import PageHead from '../../../components/PageHead';
import CustomerFormView from '../../../components/customer/CustomerFormView';
import { Card, message, Spin } from 'antd';
import Page from '../../../components/PageRouterView';
import * as $$ from '../../../utils/utility';
import './index.less';

// 查询列表 版本
function listQueryRsVersion(name) {
	return $$.ax.request({ url: 'v1/rsVersion/listQuery', type: 'get', data: { name }, service: 'oper' });
}

// 查询列表 增强包
function listQueryRsMeal(name) {
	return $$.ax.request({ url: 'v1/rsMeal/listQuery', type: 'get', data: { name }, service: 'oper' });
}

// 保存修改客户信息
function saveSeCustom(data) {
	return $$.ax.request({ url: 'v1/seCustom/saveSeCustom', type: 'POST', data, service: 'oper' });
}

// 详情
function getByIdSeCustom(id) {
	return $$.ax.request({ url: 'v1/seCustom/getById', type: 'get', data: { id }, service: 'oper' });
}

const CustomerInfo = () => {
	const navigate = useNavigate();
	const [formData, setFormData] = useState({});
	const [versionList, setVersionList] = useState([]);
	const [mealList, setMealList] = useState([]);
	const [loading, setLoading] = useState(false);
	const [key, setKey] = useState(new Date().getTime());
	const params = useParams();
	//初始化组件回显
	useEffect(() => {
		getOrganization();
	}, []);

	const getOrganization = async () => {
		setLoading(true);
		const list = await listQueryRsVersion();
		const list2 = await listQueryRsMeal();
		if (params.id) {
			const data = await getByIdSeCustom(params.id);
			setFormData(data.data);
		}
		setLoading(false);
		setVersionList(list.data);
		setMealList(list2.data);
		setKey(new Date().getTime());
	};

	// 客户信息保存提交
	const customSave = async (data) => {
		setLoading(true);
		const res = await saveSeCustom({ ...data });
		if (res.type) {
			setLoading(false);
			message.success('提交成功！');
			navigate(-1);
		}
	};

	return (
		<div style={{ height: '100%', overflowX: 'hidden' }}>
			<Spin spinning={loading}>
				<PageHead
					breadcrumbData={[{ title: '客户管理', url: '/operation/customer' }, { title: params.status == '2' ? '修改客户' : '新增客户' }]}
					title={params.title ? params.title : '修改客户'}
				/>
				<div style={{ margin: '24px', backgroundColor: '#fff', padding: '24px' }}>
					<CustomerFormView key={key} list1={versionList} list2={mealList} formData={formData} status={params.status} save={customSave} />
				</div>
			</Spin>
		</div>
	);
};

export default CustomerInfo;
